Python API
==========

Views
-----

.. automodule:: dal.views
   :members:

Widgets
-------

.. automodule:: dal.widgets
   :members:

FutureModelForm
===============

.. automodule:: dal.forms
   :members:

dal_select2
===========

This is a front-end module: it provides views and widgets.

Views
-----

.. automodule:: dal_select2.views
   :members:

Widgets
-------

.. automodule:: dal_select2.widgets
   :members:

Fields
------

.. automodule:: dal_select2.fields
   :members:

Test tools
----------

.. automodule:: dal_select2.test
   :members:

dal_contenttypes
================

Fields
------

.. automodule:: dal_contenttypes.fields
   :members:

dal_select2_queryset_sequence
=============================

Views
-----

.. automodule:: dal_select2_queryset_sequence.views
   :members:

Fields
------

.. automodule:: dal_select2_queryset_sequence.fields
   :members:

Wigets
------

.. automodule:: dal_select2_queryset_sequence.widgets
   :members:

dal_queryset_sequence
=====================

Views
-----

.. automodule:: dal_queryset_sequence.views
   :members:

Fields
------

.. automodule:: dal_queryset_sequence.fields
   :members:

Widgets
-------

.. automodule:: dal_queryset_sequence.widgets
   :members:

dal_gm2m_queryset_sequence
==========================

Fields
------

.. automodule:: dal_gm2m_queryset_sequence.fields
   :members:

dal_genericm2m_queryset_sequence
================================

Fields
------

.. automodule:: dal_genericm2m_queryset_sequence.fields
   :members:

dal_gm2m
========

Fields
------

.. automodule:: dal_gm2m.fields
   :members:

dal_genericm2m
==============

Fields
------

.. automodule:: dal_genericm2m.fields
   :members:

dal_select2_taggit
==================

Fields
------

.. automodule:: dal_select2_taggit.widgets
   :members:

dal_select2_tagging
===================

Fields
------

.. automodule:: dal_select2_tagging.widgets
   :members:
